import logging
import requests
import json


class connector():
    def __init__(self, key, url="https://project-kiwi.org/api/"):
        """constructor

        Args:
            key (str): API key.
            url (str, optional): url for api, in case of multiple instances. Defaults to "https://project-kiwi.org/api/".

        Raises:
            ValueError: API key must be supplied.
        """        
        if key is None:
            raise ValueError("API key missing")

        self.key = key
        self.url = url


    def getImagery(self, project=None):
        """Get a list of imagery

        Args:
            project (str, optional): ID of the project to get all the imagery for, by default, all projects associated with user.

        Returns:
            json: list of imagery
        """        
        route = "get_imagery"
        params = {'key': self.key}
        if not project is None:
            params['project'] = project
        r = requests.get(self.url + route, params=params)
        r.raise_for_status()
        jsonResponse = r.json()
        return jsonResponse






from distutils.core import setup
setup(
  name = 'projectkiwi',         # How you named your package folder (MyLib)
  packages = ['projectkiwi'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Python tools for project-kiwi.org',   # Give a short description about your library
  author = 'Michael Thoreau',                   # Type in your name
  author_email = 'michael@project-kiwi.org',      # Type in your E-Mail
  url = 'https://github.com/michaelthoreau/projectkiwi',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/michaelthoreau/projectkiwi/archive/refs/tags/v0.1.tar.gz',    # I explain this later on
  keywords = ['GIS', 'ML', 'OTHERBUZZWORDS'],   # Keywords that define your package best
  install_requires=['requests'],
  python_requires='>=3.3',
  classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)